@@ -1,66 +1,80 @@
 import pytest
+from dirty_equals import IsDict
 from fastapi.testclient import TestClient
 
-from docs_src.body_fields.tutorial001 import app
 
-client = TestClient(app)
+@pytest.fixture(name="client")
+def get_client():
+    from docs_src.body_fields.tutorial001 import app
+
+    client = TestClient(app)
+    return client
 
 
-price_not_greater = {
-    "detail": [
+def test_items_5(client: TestClient):
+    response = client.put("/items/5", json={"item": {"name": "Foo", "price": 3.0}})
+    assert response.status_code == 200
+    assert response.json() == {
+        "item_id": 5,
+        "item": {"name": "Foo", "price": 3.0, "description": None, "tax": None},
+    }
+
+
+def test_items_6(client: TestClient):
+    response = client.put(
+        "/items/6",
+        json={
+            "item": {
+                "name": "Bar",
+                "price": 0.2,
+                "description": "Some bar",
+                "tax": "5.4",
+            }
+        },
+    )
+    assert response.status_code == 200
+    assert response.json() == {
+        "item_id": 6,
+        "item": {
+            "name": "Bar",
+            "price": 0.2,
+            "description": "Some bar",
+            "tax": 5.4,
+        },
+    }
+
+
+def test_invalid_price(client: TestClient):
+    response = client.put("/items/5", json={"item": {"name": "Foo", "price": -3.0}})
+    assert response.status_code == 422
+    assert response.json() == IsDict(
         {
-            "ctx": {"limit_value": 0},
-            "loc": ["body", "item", "price"],
-            "msg": "ensure this value is greater than 0",
-            "type": "value_error.number.not_gt",
-        }
-    ]
-}
-
-
-@pytest.mark.parametrize(
-    "path,body,expected_status,expected_response",
-    [
-        (
-            "/items/5",
-            {"item": {"name": "Foo", "price": 3.0}},
-            200,
-            {
-                "item_id": 5,
-                "item": {"name": "Foo", "price": 3.0, "description": None, "tax": None},
-            },
-        ),
-        (
-            "/items/6",
-            {
-                "item": {
-                    "name": "Bar",
-                    "price": 0.2,
-                    "description": "Some bar",
-                    "tax": "5.4",
+            "detail": [
+                {
+                    "type": "greater_than",
+                    "loc": ["body", "item", "price"],
+                    "msg": "Input should be greater than 0",
+                    "input": -3.0,
+                    "ctx": {"gt": 0.0},
                 }
-            },
-            200,
-            {
-                "item_id": 6,
-                "item": {
-                    "name": "Bar",
-                    "price": 0.2,
-                    "description": "Some bar",
-                    "tax": 5.4,
-                },
-            },
-        ),
-        ("/items/5", {"item": {"name": "Foo", "price": -3.0}}, 422, price_not_greater),
-    ],
-)
-def test(path, body, expected_status, expected_response):
-    response = client.put(path, json=body)
-    assert response.status_code == expected_status
-    assert response.json() == expected_response
+            ]
+        }
+    ) | IsDict(
+        # TODO: remove when deprecating Pydantic v1
+        {
+            "detail": [
+                {
+                    "ctx": {"limit_value": 0},
+                    "loc": ["body", "item", "price"],
+                    "msg": "ensure this value is greater than 0",
+                    "type": "value_error.number.not_gt",
+                }
+            ]
+        }
+    )
 
 
-def test_openapi_schema():
+def test_openapi_schema(client: TestClient):
     response = client.get("/openapi.json")
     assert response.status_code == 200, response.text
     assert response.json() == {
@@ -116,18 +130,39 @@ def test_openapi_schema():
                     "type": "object",
                     "properties": {
                         "name": {"title": "Name", "type": "string"},
-                        "description": {
-                            "title": "The description of the item",
-                            "maxLength": 300,
-                            "type": "string",
-                        },
+                        "description": IsDict(
+                            {
+                                "title": "The description of the item",
+                                "anyOf": [
+                                    {"maxLength": 300, "type": "string"},
+                                    {"type": "null"},
+                                ],
+                            }
+                        )
+                        | IsDict(
+                            # TODO: remove when deprecating Pydantic v1
+                            {
+                                "title": "The description of the item",
+                                "maxLength": 300,
+                                "type": "string",
+                            }
+                        ),
                         "price": {
                             "title": "Price",
                             "exclusiveMinimum": 0.0,
                             "type": "number",
                             "description": "The price must be greater than zero",
                         },
-                        "tax": {"title": "Tax", "type": "number"},
+                        "tax": IsDict(
+                            {
+                                "title": "Tax",
+                                "anyOf": [{"type": "number"}, {"type": "null"}],
+                            }
+                        )
+                        | IsDict(
+                            # TODO: remove when deprecating Pydantic v1
+                            {"title": "Tax", "type": "number"}
+                        ),
                     },
                 },
                 "Body_update_item_items__item_id__put": {
